@@ -15,7 +15,6 @@ from abc import abstractmethod
 from typing import Union, List, Callable
 from palp.network.request import Request
 from palp.network.response import Response
-from requests.cookies import RequestsCookieJar
 from palp.tool.short_module import import_module
 from palp.exception import NotGeneratorFunctionError
 from palp.controller.controller_spider_jump import JumpController
@@ -87,10 +86,6 @@ class JumpSpider:
             if request.callback is None:
                 request.callback = self.parse
 
-            # 为每一个起始函数添加一个 cookie_jar，如果有就不加
-            if not request.cookie_jar:
-                request.cookie_jar = RequestsCookieJar()
-
             self.queue.put(request)
 
     def parse(self, request: Request, response: Response) -> None:
